## dasf-messaging-python

Messaging component for python based back-end modules. Developed and tested with
Python 3.8

### Scope
This library is part of the Data Analytics Software Framework DASF (https://git.geomar.de/digital-earth/dasf), 
which was developed by the GFZ Potsdam (https://www.gfz-potsdam.de) in the Digital Earth project 
(https://www.digitalearth-hgf.de/).

### Howto use it

see: https://git.geomar.de/digital-earth/dasf/dasf-messaging-python/-/blob/legacy_v0.0.x/ExampleMessageConsumer.py
